import React from 'react';

//module
import moment from 'moment';
import firebase from '@react-native-firebase/app';

//widget
import { Button, Input } from 'native-base';

//data type
import { CommentFooterProps } from './type';

const Footer = ({ collection, doc, writer, collectionData }: CommentFooterProps) => {
    const [commentTxt, setCommentTxt] = React.useState<string>('');
    const [btnLoading, setBtnLoading] = React.useState<boolean>(false);

    const onCommentSend = async () => {
        try {
            let Ref = firebase.firestore().collection(collection).doc(doc);

            await Ref.collection('comment').add({
                writer_avatar: writer.avatar,
                writer_name: writer.name,
                writer_address: writer.decs,
                comment_decs: commentTxt,
                comment_create_date: moment().format('YYYY-MM-DD HH:mm:ss'),
            });

            return new Promise<void>((resolve, reject) => {
                firebase.firestore().runTransaction(async (transaction) => {
                    const res = await transaction.get(Ref);
                    if (!res.exists) {
                        resolve();
                    }
                    let data = res.data();

                    if (data) {
                        let count = data.commentValue ? data.commentValue : 0;

                        count += 1;

                        transaction.update(Ref, {
                            commentValue: count,
                        });
                    }
                    resolve();
                });
            });
        } catch (err) {
            return Promise.reject({
                function: 'onCommentSend',
                error: err,
            });
        }
    };

    return (
        <>
            <Input flex={1} marginRight={3} placeholder="댓글을 입력해주세요." value={commentTxt} onChangeText={setCommentTxt} />
            <Button
                variant="outline"
                isLoading={btnLoading}
                isDisabled={commentTxt === ''}
                onPress={async () => {
                    setBtnLoading(true);
                    await onCommentSend();
                    setCommentTxt('');
                    setBtnLoading(false);
                }}
            >
                작성
            </Button>
        </>
    );
};

export default Footer;
