import React from 'react';

//module
import moment from 'moment';

//data type
import { FirebaseFirestoreTypes } from '@react-native-firebase/firestore';

export type firebaseWhereType = {
    fieldPath: string | number | FirebaseFirestoreTypes.FieldPath;
    opStr: FirebaseFirestoreTypes.WhereFilterOp;
    value: any;
};
export type firebaseOrderByType = { fieldPath: string | number | FirebaseFirestoreTypes.FieldPath; directionStr?: 'asc' | 'desc' | undefined };

export type firebaseListProps = {
    store?: { id: string; name: string; avatar: string };
    where?: firebaseWhereType[];
    orderBy?: firebaseOrderByType;
    getStore?: boolean;
};

export const onSnapshot = async <ItemType extends { key: string }>(props: {
    snapshot?: FirebaseFirestoreTypes.DocumentSnapshot[];
    onDoc: (doc: FirebaseFirestoreTypes.DocumentSnapshot<FirebaseFirestoreTypes.DocumentData>) => ItemType;
    onException?: (item: ItemType) => Promise<ItemType>;
}) => {
    const { snapshot, onDoc, onException } = props;
    let list: ItemType[] = [];

    if (snapshot) {
        const promises = snapshot.map(async (doc) => {
            let data = doc.data();

            if (data) {
                let db = onDoc(doc);
                if (onException) {
                    db = await onException(db);
                }
                list.push(db);
            }
        });
        await Promise.all(promises);
    }

    return list;
};

export const TimeFormat = ({ time, format }: { time: string | null; format: string }) => {
    if (time) {
        let title = '';
        var date = moment().format('YYYY-MM-DD HH:mm:ss'); // 현재 시간
        var diffr = moment.duration(moment(date).diff(moment(time)));
        var hours = parseInt(diffr.asHours().toString());
        var minutes = parseInt(diffr.minutes().toString());

        if (hours === 0) {
            if (minutes === 0) {
                title = '방금전';
            } else {
                title = `${minutes}분전`;
            }
        } else if (hours < 24) {
            title = `${hours}시간전`;
        } else {
            title = moment(time).format(format);
        }

        return title;
    }
};
